
## API Reference

The [`scenedetect` API reference](https://manual.scenedetect.com/en/v0.6/api.html) is available as part of the [PySceneDetect Manual](http://manual.scenedetect.com/). See the [Quickstart](https://manual.scenedetect.com/en/v0.6/api.html#quickstart) and [Example](https://manual.scenedetect.com/en/v0.6/api.html#example) sections to get started.
